==> tine20-voip_2019.12.5.tar.bz2: Phone/js/Phone-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nLanguage: vi\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Call"
: "Gọi"

, "Calls"
: "Các cuộc gọi"

, "Line"
: "Đường dây"

, "Caller Id"
: "Mã người gọi"

, "Start"
: "Bắt đầu"

, "Connected"
: "Đã kết nối"

, "Disconnected"
: "Đã ngắt kết nối"

, "Duration"
: "Thời lượng"

, "Ringing"
: "Đang reo"

, "Direction"
: "Trực tiếp"

, "Source"
: "Nguồn"

, "Destination"
: "Đích đến"

, "Phone"
: ""

, "Phones"
: "Điện thoại"

, "Settings"
: "Thiết lập"

, "Lines"
: "Đường dây"

, "Description"
: "Mô tả"

, "Number"
: "Số"

, "Cancel"
: "Hủy"

, "Dial"
: "Quay số"

, "Error"
: "Lỗi"

, "Not possible to dial."
: "Không thể quay số"

, "Edit phone settings"
: "Sửa thiết lập điện thoại"

, "Dial number"
: "Quay số"

, "Initiate a new outgoing call"
: "Bắt đầu 1 cuộc gọi đi mới"

, "No phone selected"
: "Chưa chọn điện thoại"

, "Please select the desired phone in the tree!"
: "Xin chọn điện thoại bạn muốn trong cây danh mục"

, "Call contact"
: "Liên lạc điện thoại"

, "Work"
: "Cơ quan"

, "Home"
: "Nhà riêng"

, "Cell"
: "Di động"

, "Cell private"
: "Di động riêng"

, "Incoming call"
: "Cuộc gọi đến"

, "Outgoing call"
: "Cuộc gọi đi"

, "unknown number"
: "không rõ số"

, "local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "identifies if a calling number is a local call without leading area code"
: ""

, "own telephone number"
: ""

, "own telephone number to prefix to internal calls"
: ""

, "Calls this week"
: "Cuộc gọi trong tuần"

, "Incoming and outgoing calls of this week"
: "Cuộc gọi đi và đến trong tuần"

, "Calls last week"
: "Cuộc gọi tuần trước"

, "Incoming and outgoing calls of last week"
: "Cuộc gọi đi và đến tuần trước"

, "Calls this month"
: "Cuộc gọi tháng này"

, "Incoming and outgoing calls of this month"
: "Cuộc gọi đi và đến tháng này"

, "Calls last month"
: "Cuộc gọi tháng trước"

, "Incoming and outgoing calls of last month"
: "Cuộc gọi đi và đến tháng trước"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;

==> tine20-voip_2020.03.4.tar.bz2: Phone/js/Phone-lang-vi-debug.js <==
/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Phone **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Phone'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2017-09-28 09:49+0000\nLast-Translator: sstamer <s.stamer@metaways.de>\nLanguage-Team: Vietnamese (http://www.transifex.com/tine20/tine20/language/vi/)\nLanguage: vi\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Incoming call"
: "Cuộc gọi đến"

, "Outgoing call"
: "Cuộc gọi đi"

, "unknown number"
: "không rõ số"

, "Phone"
: ""

, "Line"
: "Đường dây"

, "Number"
: "Số"

, "Cancel"
: "Hủy"

, "Dial"
: "Quay số"

, "Error"
: "Lỗi"

, "Not possible to dial."
: "Không thể quay số"

, "Call contact"
: "Liên lạc điện thoại"

, "Work"
: "Cơ quan"

, "Home"
: "Nhà riêng"

, "Cell"
: "Di động"

, "Cell private"
: "Di động riêng"

, "Edit phone settings"
: "Sửa thiết lập điện thoại"

, "Dial number"
: "Quay số"

, "Initiate a new outgoing call"
: "Bắt đầu 1 cuộc gọi đi mới"

, "Phones"
: "Điện thoại"

, "No phone selected"
: "Chưa chọn điện thoại"

, "Please select the desired phone in the tree!"
: "Xin chọn điện thoại bạn muốn trong cây danh mục"

, "Calls this week"
: "Cuộc gọi trong tuần"

, "Calls last week"
: "Cuộc gọi tuần trước"

, "Calls this month"
: "Cuộc gọi tháng này"

, "Calls last month"
: "Cuộc gọi tháng trước"

, "Incoming and outgoing calls of this week"
: "Cuộc gọi đi và đến trong tuần"

, "Incoming and outgoing calls of last week"
: "Cuộc gọi đi và đến tuần trước"

, "Incoming and outgoing calls of this month"
: "Cuộc gọi đi và đến tháng này"

, "Incoming and outgoing calls of last month"
: "Cuộc gọi đi và đến tháng trước"

, "Local prefix for outgoing calls"
: ""

, "telephone area code"
: ""

, "regex for local calls"
: ""

, "Identifies if a calling number is a local call without leading area code."
: ""

, "own telephone number"
: ""

, "Own telephone number to prefix to internal calls."
: ""

, "Call"
: "Gọi"

, "Calls"
: "Các cuộc gọi"

, "Caller Id"
: "Mã người gọi"

, "Start"
: "Bắt đầu"

, "Connected"
: "Đã kết nối"

, "Disconnected"
: "Đã ngắt kết nối"

, "Duration"
: "Thời lượng"

, "Ringing"
: "Đang reo"

, "Direction"
: "Trực tiếp"

, "Source"
: "Nguồn"

, "Destination"
: "Đích đến"

, "resolved destination"
: ""

, "Settings"
: "Thiết lập"

, "Lines"
: "Đường dây"

, "Description"
: "Mô tả"

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true;
